@@ -85,13 +85,16 @@ class CfgFileReader(threading.Thread):
 	    f.write('UPLOAD'+str(i)+'=Macro(FILL_LIST);\n')   
 
 	    f.write('[ModeEnd]\n')    
-	    f.write(fillCMD+');Set(menu,replace,Select,Regenerate);\n')    
+	    f.write(fillCMD+');Macro(REGEN_MENU);\n')    
 	    f.write('[End]\n')    
 	    f.close()
 	    
     def processOneFile(self,cfgFile):
 	
 	ret = []
+	if not os.path.isfile(cfgFile):
+	    return ret
+	    
 	fd = open(cfgFile,'r') 
 	n = os.path.basename(cfgFile)
 	n = n[:len(n)-4]
