@@ -2,8 +2,8 @@
 // anyRemote
 // a bluetooth remote for your PC.
 //
-// Copyright (C) 2006-2011 Mikhail Fedotov <anyremote@mail.ru>
-// 
+// Copyright (C) 2006-2012 Mikhail Fedotov <anyremote@mail.ru>
+//
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
@@ -13,10 +13,10 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. 
+// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
 #ifndef _PARSE_H_
@@ -45,17 +45,17 @@
 // Some AT stuff
 // \r will be added before send
 #define DEF_AT_CMER_ON_DEFAULT   "AT+CMER=3,2,0,0,0" 	// Default, valid for SE and Siemens S55 phones
-#define DEF_AT_CMER_OFF_DEFAULT  "AT+CMER=0,0,0,0,0" 
+#define DEF_AT_CMER_OFF_DEFAULT  "AT+CMER=0,0,0,0,0"
 #define DEF_AT_CMER_ON_SE        "AT+CMER=3,2,0,0,0" 	// SE, same as default
-#define DEF_AT_CMER_OFF_SE       "AT+CMER=0,0,0,0,0" 
+#define DEF_AT_CMER_OFF_SE       "AT+CMER=0,0,0,0,0"
 #define DEF_AT_CMER_ON_MOTOROLA  "AT+CMER=3,1,0,0,0" 	// Motorola phones	
-#define DEF_AT_CMER_OFF_MOTOROLA "AT+CMER=0,0,0,0,0" 
+#define DEF_AT_CMER_OFF_MOTOROLA "AT+CMER=0,0,0,0,0"
 #define DEF_AT_CMER_ON_SAGEM     "AT+CMER=2,1,0,0,0" 	// Sagem phones
-#define DEF_AT_CMER_OFF_SAGEM    "AT+CMER=0,0,0,0,0" 
+#define DEF_AT_CMER_OFF_SAGEM    "AT+CMER=0,0,0,0,0"
 #define DEF_AT_CMER_ON_SIEMENS   "AT+CMER=3,2,0,0,0" 	// Siemens phones, same as default
-#define DEF_AT_CMER_OFF_SIEMENS  "AT+CMER=0,0,0,0,0" 
+#define DEF_AT_CMER_OFF_SIEMENS  "AT+CMER=0,0,0,0,0"
 
-#define DEF_AT_CGMI     "AT+CGMI" 
+#define DEF_AT_CGMI     "AT+CGMI"
 #define DEF_AT_CLCC     "AT+CLCC"		// ? will be added later (will try both variants)
 #define DEF_AT_CSCS     "AT+CSCS="
 #define DEF_AT_CKPD 	"AT+CKPD="
@@ -73,11 +73,11 @@
 #define SAME 	    	99
 #define PAUSE_STR   	"PAUSE"
 
-#define ID_EVT_INIT	      1 	     
-#define ID_EVT_EXIT	      2 	     
-#define ID_EVT_CONNECT        3 	     
-#define ID_EVT_DISCONNECT     4 	     
-#define ID_EVT_ENDCALL        5     
+#define ID_EVT_INIT	      1
+#define ID_EVT_EXIT	      2
+#define ID_EVT_CONNECT        3
+#define ID_EVT_DISCONNECT     4
+#define ID_EVT_ENDCALL        5
 
 #define EVT_INIT     	"(Init)"
 #define EVT_EXIT        "(Exit)"
@@ -114,13 +114,13 @@
 #define CMD_TIMER               "Timer"
 #define CMD_SEND                "Send"                 	// Server mode only, used for Bemused-server emulation
 #define CMD_EXECSEND            "ExecAndSend"        	// Server mode only, used for Bemused-server emulation
-#define CMD_MACRO               "Macro"            
-#define CMD_LOAD                "Load"            
-#define CMD_INCLUDE             "Include"            
+#define CMD_MACRO               "Macro"
+#define CMD_LOAD                "Load"
+#define CMD_INCLUDE             "Include"
 #define CMD_GET             	"Get"      		// Server mode only      
-#define CMD_MAKE             	"Make" 
-#define CMD_EMU             	"Emulate" 
-#define CMD_DBUS             	"Dbus" 
+#define CMD_MAKE             	"Make"
+#define CMD_EMU             	"Emulate"
+#define CMD_DBUS             	"Dbus"
 
 #define SET_BG         "bg"
 #define SET_PARAM      "parameter"
@@ -142,6 +142,7 @@
 #define SET_VOLUME     "volume"
 #define SET_IMAGE      "image"
 #define SET_COVER      "cover"
+#define SET_POPUP      "popup"
 
 #define MAKE_DISCONN    "disconnect"
 #define MAKE_MODE       "mode"
@@ -158,7 +159,7 @@
 #define ID_FONT        2
 #define ID_ICONS       3
 #define ID_SKIN        4
-#define ID_STATUS      5    
+#define ID_STATUS      5
 #define ID_TITLE       6
 #define ID_VOLUME      7
 #define ID_COVER       8
@@ -189,58 +190,52 @@
 #define AUTOREPEAT_STR	"AutoRepeat"
 #define CHARSET_STR    	"CharSet"
 
-typedef struct Td
-{
-	//char       id[MAXARGLEN];
-	int        timeout;
-        int	   times;
+typedef struct Td {
+    //char       id[MAXARGLEN];
+    int        timeout;
+    int	   times;
 } timerData;
 
-typedef struct Ci
-{
-	int        type;
-        char       *descr;
-        char       *exec;
-        timerData  *tdata;
-        struct Ci  *next;
+typedef struct Ci {
+    int        type;
+    char       *descr;
+    char       *exec;
+    timerData  *tdata;
+    struct Ci  *next;
 } cmdItem;
 
-typedef struct Tk
-{
-	char        *key;
-        cmdItem     *cmd;
-        struct Tk   *next;
+typedef struct Tk {
+    char        *key;
+    cmdItem     *cmd;
+    struct Tk   *next;
 } type_key;
 
-typedef struct Mt
-{
-	char        name[MTEXTLEN];
-        type_key*   keys;
-        struct Mt   *next;
+typedef struct Mt {
+    char        name[MTEXTLEN];
+    type_key*   keys;
+    char        parent[MTEXTLEN];
+    struct Mt   *next;
 } mode;
 
-typedef struct Cp
-{
-	char       index[6];
-        char       value[MAXARGLEN];
+typedef struct Cp {
+    char       index[6];
+    char       value[MAXARGLEN];
 } cmdParams;
 
-typedef struct
-{
-        int   model;
-        char* cfgDir;
-        int   frontEnd;
-        int   http;
-        int   pass;
-        uid_t   uid;
-	gid_t   gid;
+typedef struct {
+    int   model;
+    char* cfgDir;
+    int   frontEnd;
+    int   http;
+    int   pass;
+    uid_t   uid;
+    gid_t   gid;
 } CONF;
 
-typedef struct Ta
-{
-	char        *file;
-        char        *macro;
-        struct Ta   *next;
+typedef struct Ta {
+    char        *file;
+    char        *macro;
+    struct Ta   *next;
 } type_alarm;
 
 // Exported functions definitions
@@ -253,5 +248,6 @@ int   storeCmds         (cmdItem** cmdList, char *value);
 int   load_cfg		(char *mfile, int isInit);
 int   cmdSet2id         (const char *what_to_set);
 void  setMode           (const char *modeName);
+mode* findMode		(const char *name);
 
 #endif
